@@ -89,6 +89,10 @@ values:
    one, or the default project that is being used, for users accessing
    the platform from the outside.
 
+.. py:data:: USER_AGENT
+
+   The user agent string that dxpy will send to the server with each request.
+
 The :func:`dxpy.DXHTTPRequest` function uses the ``DX_SECURITY_CONTEXT``
 and ``DX_APISERVER_*`` variables to select an API server and provide
 appropriate authentication headers to it. (Note: all methods in the
@@ -130,7 +134,7 @@ environment variables:
 # except:
 #     pass
 
-import os, json, time, logging, httplib
+import os, json, time, logging, httplib, platform
 from .packages import requests
 from .packages.requests.exceptions import ConnectionError, HTTPError, Timeout
 from .packages.requests.auth import AuthBase
@@ -159,6 +163,10 @@ SESSION_HANDLER=requests.session()
 
 DEFAULT_RETRIES = 5
 
+USER_AGENT = "{name}/{version} ({platform})".format(name=__name__,
+                                                    version=TOOLKIT_VERSION,
+                                                    platform=platform.platform())
+
 http_server_errors = set([requests.codes.server_error,
                           requests.codes.bad_gateway,
                           requests.codes.service_unavailable,
@@ -170,7 +178,7 @@ class ContentLengthError(HTTPError):
 
 def DXHTTPRequest(resource, data, method='POST', headers={}, auth=True, timeout=600, config=None,
                   use_compression=None, jsonify_data=True, want_full_response=False,
-                  prepend_srv=True,
+                  prepend_srv=True, session_handler=SESSION_HANDLER,
                   max_retries=DEFAULT_RETRIES, always_retry=False, **kwargs):
     '''
     :param resource: API server route, e.g. "/record/new"
@@ -253,7 +261,8 @@ def DXHTTPRequest(resource, data, method='POST', headers={}, auth=True, timeout=
         rewind_input_buffer_offset = data.tell()
 
     headers['DNAnexus-API'] = API_VERSION
-    headers['User-Agent'] = "dxpy/" + TOOLKIT_VERSION
+    headers['User-Agent'] = USER_AGENT
+
     if use_compression == 'snappy':
         if not snappy_available:
             raise DXError("Snappy compression requested, but the snappy module is unavailable")
@@ -268,7 +277,7 @@ def DXHTTPRequest(resource, data, method='POST', headers={}, auth=True, timeout=
     for retry in range(max_retries + 1):
         streaming_response_truncated = False
         try:
-            response = SESSION_HANDLER.request(method, url, data=data, headers=headers, timeout=timeout,
+            response = session_handler.request(method, url, data=data, headers=headers, timeout=timeout,
                                                auth=auth, config=config, **kwargs)
 
             if _UPGRADE_NOTIFY and response.headers.get('x-upgrade-info', '').startswith('A recommended update is available') and not os.environ.has_key('_ARGCOMPLETE'):
