@@ -120,7 +120,7 @@ def download_dxfile(dxid, filename, chunksize=DEFAULT_BUFFER_SIZE, append=False,
     bytes = 0
 
     mode = 'ab' if append else 'wb'
-    with DXFile(dxid, project=project, read_buffer_size=chunksize) as dxfile, open(filename, mode) as fd:
+    with DXFile(dxid, mode='r', project=project, read_buffer_size=chunksize) as dxfile, open(filename, mode) as fd:
         if show_progress:
             print_progress(0, None)
         while True:
